@@ -4,14 +4,15 @@ use warnings;
 
 package Pod::Elemental::Transformer::Splint::MethodRenderer::HtmlDefault;
 
-our $VERSION = '0.1200'; # VERSION
+our $VERSION = '0.1201'; # VERSION
 # ABSTRACT: Default html method renderer
 
 use Moose;
 use namespace::autoclean;
 use Path::Tiny;
 use Pod::Simple::XHTML;
-use List::AllUtils qw/any uniq/;
+use List::Util qw/any/;
+use List::MoreUtils qw/uniq/;
 use syntax 'qs';
 
 with 'Pod::Elemental::Transformer::Splint::MethodRenderer';
@@ -200,7 +201,7 @@ Pod::Elemental::Transformer::Splint::MethodRenderer::HtmlDefault - Default html
 
 =head1 VERSION
 
-Version 0.1200, released 2016-02-02.
+Version 0.1201, released 2016-02-03.
 
 =head1 SOURCE
 
